==> qore-1.0.8.tar.bz2: qore-1.0.8/docs/modules/ServiceNowRestDataProvider/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore ServiceNowRestDataProvider Module Reference", "index.html", [
    [ "ServiceNowRestDataProvider Module", "index.html", [
      [ "Introduction to the ServiceNowRestDataProvider Module", "index.html#servicenowrestdataproviderintro", [
        [ "ServiceNowRestDataProvider v1.1", "index.html#servicenowrestdataprovider_v1_1", null ],
        [ "ServiceNowRestDataProvider v1.0.1", "index.html#servicenowrestdataprovider_v1_0_1", null ],
        [ "ServiceNowRestDataProvider v1.0", "index.html#servicenowrestdataprovider_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__crypto__transformations.html#gab9ae17ec1fae8d177132b6abbe94dfb4",
"group__error__constants.html#ga5c12fa2b92239e05f97252a478ffd2da",
"group__library__functions.html#ga13d9bb498eef9caffe641130bd8a1c73",
"group__misc__functions.html#ga82506074037fe39372ea4f44e2582a75",
"group__query__op__funcs.html#ga82445e3bda9cbd213c71c8f3b1f8d675",
"group__tattr__control__mode__constants.html#ga0063c1dc72c5f1cc155447e12d7787f4"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';

==> qore-1.0.10.tar.bz2: qore-1.0.10/docs/modules/ServiceNowRestDataProvider/html/navtreedata.js <==
/*
@ @licstart  The following is the entire license notice for the
JavaScript code in this file.

Copyright (C) 1997-2017 by Dimitri van Heesch

This program is free software; you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation; either version 2 of the License, or
(at your option) any later version.

This program is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

You should have received a copy of the GNU General Public License along
with this program; if not, write to the Free Software Foundation, Inc.,
51 Franklin Street, Fifth Floor, Boston, MA 02110-1301 USA.

@licend  The above is the entire license notice
for the JavaScript code in this file
*/
var NAVTREE =
[
  [ "Qore ServiceNowRestDataProvider Module Reference", "index.html", [
    [ "ServiceNowRestDataProvider Module", "index.html", [
      [ "Introduction to the ServiceNowRestDataProvider Module", "index.html#servicenowrestdataproviderintro", [
        [ "ServiceNowRestDataProvider v1.1", "index.html#servicenowrestdataprovider_v1_1", null ],
        [ "ServiceNowRestDataProvider v1.0.1", "index.html#servicenowrestdataprovider_v1_0_1", null ],
        [ "ServiceNowRestDataProvider v1.0", "index.html#servicenowrestdataprovider_v1_0", null ]
      ] ]
    ] ],
    [ "Modules", "modules.html", "modules" ],
    [ "Namespaces", "namespaces.html", [
      [ "Namespace List", "namespaces.html", "namespaces_dup" ],
      [ "Namespace Members", "namespacemembers.html", [
        [ "All", "namespacemembers.html", null ],
        [ "Functions", "namespacemembers_func.html", null ],
        [ "Variables", "namespacemembers_vars.html", null ]
      ] ]
    ] ],
    [ "Classes", "annotated.html", [
      [ "Class List", "annotated.html", "annotated_dup" ],
      [ "Class Index", "classes.html", null ],
      [ "Class Members", "functions.html", [
        [ "All", "functions.html", null ],
        [ "Functions", "functions_func.html", null ],
        [ "Variables", "functions_vars.html", null ]
      ] ]
    ] ]
  ] ]
];

var NAVTREEINDEX =
[
"annotated.html",
"group__crypto__transformations.html#gab9ae17ec1fae8d177132b6abbe94dfb4",
"group__error__constants.html#ga5c12fa2b92239e05f97252a478ffd2da",
"group__library__functions.html#ga13d9bb498eef9caffe641130bd8a1c73",
"group__misc__functions.html#ga82506074037fe39372ea4f44e2582a75",
"group__query__op__funcs.html#ga378a50f280c92e2bb7983f0a8cc65e1a",
"group__tattr__control__character__constants.html#gaee9526a9d666c265e0ca0d00dd41a2be"
];

var SYNCONMSG = 'click to disable panel synchronisation';
var SYNCOFFMSG = 'click to enable panel synchronisation';
